@@ -28,6 +28,7 @@ from yd_commands.config import (
     link_entity,
     load_config_worker_pool,
 )
+from yd_commands.config_keys import USERDATA, USERDATAFILE
 from yd_commands.mustache import (
     load_json_file_with_mustache_substitutions,
     load_jsonnet_file_with_mustache_substitutions,
@@ -99,7 +100,7 @@ def create_worker_pool_from_json(wp_json_file: str) -> None:
             ("requirementNamespace", CONFIG_COMMON.namespace),
             ("requirementTag", CONFIG_COMMON.name_tag),
             ("templateId", CONFIG_WP.template_id),
-            ("userData", CONFIG_WP.user_data),
+            ("userData", get_user_data_property()),
             ("imagesId", CONFIG_WP.images_id),
             ("instanceTags", CONFIG_WP.instance_tags),
             ("targetInstanceCount", CONFIG_WP.target_instance_count),
@@ -218,7 +219,7 @@ def create_worker_pool():
                 requirementName=id,
                 targetInstanceCount=batches[batch_number].initial_nodes,
                 requirementTag=CONFIG_COMMON.name_tag,
-                userData=CONFIG_WP.user_data,
+                userData=get_user_data_property(),
                 imagesId=CONFIG_WP.images_id,
                 instanceTags=CONFIG_WP.instance_tags,
             )
@@ -325,6 +326,21 @@ def generate_wp_batch_name(
     return name
 
 
+def get_user_data_property() -> Optional[str]:
+    """
+    Get the 'userData' property, either using the contents of the file
+    specified in 'userDataFile' or using the string specified in 'userData'.
+    Raise exception if both 'userData' and 'userDataFile' are set.
+    """
+    if CONFIG_WP.user_data and CONFIG_WP.user_data_file:
+        raise Exception(f"Only one of '{USERDATA}' or '{USERDATAFILE}' should be set")
+    if CONFIG_WP.user_data:
+        return CONFIG_WP.user_data
+    if CONFIG_WP.user_data_file:
+        with open(CONFIG_WP.user_data_file, "r") as f:
+            return f.read()
+
+
 # Entry point
 if __name__ == "__main__":
     main()
